bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 14. Aventiure
___________________________________________________ #### Auentv wie die chvniginne mit ander zerwrfen
| ### <Vor> einer <vespercite> man vfem hove sach ### ze rossen manigen rechen hvsir vn– dach ### was allez vol durch [31v]schowen von luten vber al ### do warn ovch die frowen zen venstern chomen in den sal ### Zesamene do gesazen die kuniginne rich ### si reiten von zwein rechen die waeren lobelich ### do sprach div frowe Chriemh' ich han einen man ### daz elliv disiv riche zvo sinen henden solden stan
###### 825 | ### Des anwtwrt ir Prunhilt daz mohte vil wol sin ### ob niemen mere enlebte wan sin vn– din ### so mohten im div riche wol wesn vndertann ### die wile aber lebt Gunther so chundez nimmer ergan
###### 826 | ### Do sprach aber Chriemh' nv sihstv wier stat ### wie rehte herrenliche er vor den rechen gat ### alsam der liehte mane vor den sternen stat ### des mvz ich wol von schulden tragen vrolichen mvot
###### 827 | ### Do sprach div hvsfrowe swie wætlich si din man ### swie schone vn– swie biderbe so mvstv vor im lan ### Gunthern den rechen den edeln prvder din ### der mvz vor allen kunigen mit lobe wærliche sin
| ### Des antwrt ir Chriemh' so tiwer ist wol min man ### daz ich in ane schulde niht gelobet han ### an vil manigen tvgenden ist sin ere groz ### gelovbestv des Prvnh' er ist wol Gunthers genoz
###### 829 | ### Iane soltv mir ez Chriemhilt zarge niht vervan ### wande ich doch ane schulde die rede niht han getan ### ich hort si iehn beide do ihs alrerste sach ### vn– da des kuniges wille am mime libe geschach
###### 830 | ### <vn–> da er mine minne so ritterlich gewan ### do iach des selbe Sivrit er w re skuniges man ### des han ich in fvr eigen sit ihs in horte iehn ### do sprach div frowe Chriemhilt so wær mir vbel geschehn
###### 831 | ### Wie heten so geworben die edeln bruder min ### daz ich eigen mannes wine solde sin ### des wil ich dich Prunh' vil vriuntlichen biten ### daz dv die rede lazest mit vil minneklichen siten
| ### Ine mag ir niht gelazen sprach do des kuniges wip ### zwiv sold ich verchiesen so maniges rechen lip ### der uns mit dem kunige ist dienstlich undertan ### mich mvete daz ich so lange niht zinsse von im gehabt han
###### 833 | ### Dv mvst in von im verchiesen daz er dir nimmer bi ### wone deheiner dienste er ist tivrrer danne si ### Gunther minn brvder dv solt nimmer daz gelebn ### daz er dir zinss deheinen von sinen landen mvze gebn
###### 834 | ### Dv zivhest dich ze hohe sprach aber des kuniges wip ### nv wil ich sehn gerne ob man den dinen lip ### habe ze solhen eren als man den minen tvot ### die frowen waren beide harte zornich gemvot
| ### Do sprach div frowe Chriemh' daz mvz et nv geschehn ### sit dv mines mannes fvr eigen hast veriehn ### nv mvozen hivte chiesen der zweier kunige man ### ob ich vor kuniges wibe tvrre zvo der kirchen gan
###### 836 | ### Ich laze dich wol schowen daz ich bin adel vri ### min man ist verre tiwere danne der dine si ### da mite wil ich selbe niht bescholten sin ### dv mvste daz hinte chiesen wie div eigene div din
###### 837 | ### ze hove ge vor rechen in Buregonde [32r]lant ### ich wil selbe wesn edeler danne iemen habe bechant ### deheine kuniginne div chrone ie her getrvoch ### do hvop sich vnder den frowen grozes nides genvoch
| ### Do sprach aber Prunh' wiltv niht eigen sin ### so mvstv dich scheiden von den frowen min ### mit dinem ingesinde da wir zem mvnster gan ### entriwen sprach do Chriemh' daz sol werden getan
###### 839 | ### Nv kleidet ivch min mægede sprach Sivrides wip ### ez mvz ane schande beliben hie min lip ### ir svlt daz lazen schowen vn– habt ir riche wat ### si mac sin lovgen gerne des Prunh' veriehn hat
###### 840 | ### Man moht in lihte raten si svchten richiv chleit ### da wart vil wol gezieret manic frowe vn– meit ### do gie mit ir <gesinde> des edeln wirtes wip ### ze wnsche wart gechleidet der schonen Chriemh' lip
###### 841 | ### mit drin un– vierzech meiden di brahtes an den Rin ### die trugen liehte pfellel geworht in Arabin ### sus chomen zv dem munster die meide wolgetan ### in warten vor dem huose alle Sivrides man
| ### Die lute nam des wnder wa von daz geschach ### daz man die kuniginne nv gescheiden sach ### daz si niht bi ein ander giengen alsam ê ### da von wart manigem degene sit vil sorchlichen we
###### 843 | ### Hie stvnt vor dem munster daz Guntheres wip ### do hete kurcewile vil maniges rechen lip ### mit den schonen frowen der si da namen war ### do chome div edel Chriemh' mit maniger herlichen schar
###### 844 | ### Swaz kleider ie getrugen edeler ritter kint ### wider ir gesinde was iz gar ein wint ### si was so rich des gvtes daz drizech kunige wip ### niht mohten wol erzivgen daz tet der Chriemh' lip
###### 845 | ### Ob iemen wnschen solde der chunde niht gesagn ### daz man so richer chleider geschehe ie mer getragn ### als in der wile trvogen ir meide wolgetan ### wan ze leide Prunhilde ez hete Chriemh' verlan
| ### Zesamne si do chomen vor dem munster wit ### ez tet div husfrowe durch einen grozen nit ### die edeln Chriemh' hiez si stille stan ### ia sol vor kuniges wibe nimmer eigen div gegan
###### 847 | ### Do sprach div frowe Chriemh' zornic was ir mvot ### chundest noch geswigen daz wære dir gvot ### dv hast geschendet selbe den dinen schonen lip ### wie mac immer chebse mit rehte werden chuniges wip
###### 848 | ### Wen hastv hie verchebset sprach des kuniges wip ### daz tvn ich dich sprach Chriemh' den dinen schonen lip ### minnet erste Sivrit min vil lieber man ### ia enwas ez niht min brvoder der dir den magetvom an gewan
###### 849 | ### War chomen dine sinne ez was ein arger list ### zwiv lieze du in minnen sit er din eigen ist ### ich hore dich sprach Chriemh' ane alle schulde klagn ### entriwen sprach do Privnh' daz wil ich Gunthere sagn
###### 850 | ### Dich hat din vbermvete sprach Chriemh' betrogen ### dv hast mich ze dienste mit rede dich an gezogen ### daz wizze in rehten triwen ez ist mir immer leit ### getriwer hein[32v]liche wirde ich dir nimmer mer bereit
| ### Prvnh' do weinde Chriemh' niht langer lie ### vor des kuniges wibe inz mvnster si do gie ### mit ir ingesinde do hvop sich grozer haz ### des wrden liehtiv ovgen vil starche trvebe vn– naz
###### 852 | ### Swaz man gote gediente oder iemen da gesanch ### des duhte Prunh' div wile gar ze lanch ### <wande> ir was vil trvebe der lip vn– al der mvot ### des mvsin sit engelten rechen chvene vn– gvot
###### 853 | ### Prvnh' mit ir frowen gie fvr daz munster stan ### si gedahte mich mvz Chriemh' mere horen lan ### des mich so lvte <zihet> daz <worthorte> wip ### vn– hat er <sichs> gervemet ez gat Sivride an den lip
###### 854 | ### Nv chome div <frau> Chriemh' mit manigem chvnen man ### do sprach div husvrowe ir sult mich ez lan <verstan> ### <ir> iahet min ze chebsen daz sult ir lazen sehn ### vn– sult ez hie bew ren wa mir daz laster si geschehen
| ### Do sprach div schone Chriemh' ir moeht mich lazen <gan> ### ich erzivgez mit dem golde daz ich an der hende han ### daz brahte mir min vriedel do er erste bi dir gelach ### nie gelebte Prunh' deheinen leidern tach
###### 856 | ### Diz golt ich wol erchenne ez wart mir verstoln ### sprach div kuniginne vn– ist lange mich verholn ### ich chvm es an ein ende wer mirz habe genomen ### die frowen beide waren in groz vngemvote chomen
###### 857 | ### Do sprach aber Chriemh' ine wils niht wesn diep ### dv mohtes wol gedaht han vn– wære dir ere liep ### ich erzivgez mit dem gurtel den ich hie vmbe han ### daz ich ez niht enlivge ia wart min Sivrit din man
###### 858 | ### Von Ninnive der siden si den porten trvoch ### von edelem gesteine gvot was er genvoch ### do den Prunh' gesach weinen si began ### daz mvse vreischen Gunther vn– alle Buregonde man
| ### Do sprach div kuniginne heizet her gan ### den fursten vom Rine ich wil in horen lan ### wie mich hat gehoenet siner swester lip ### si sagt hie offenliche ich si Sivrides wip
###### 860 | ### Der kunic chome mit rechen weinen er do sach ### die sinen truetinne wie gvtlich er sprach ### saget mir liebiv frowe waz ist iv getan ### si sprach vil lieber herre von schulden mvoz ich trurich stan
###### 861 | ### Von allen minen eren mich div swester din ### gerne wolde scheiden dir sol geklaget sin ### si giht mich habe gechebset Sivrit ir man ### do sprach der kunic Gunther so hetes vbele getan
###### 862 | ### Si treit hie minen gurtil den ich lange han verlorn ### vn– ovch min guldin vingerlin daz ich ie wart geborn ### daz mvoz mich immer riwen dvne beredest mich ### kunic der grozen schanden daz diene ich immer vmbe dich
###### 863 | ### Do sprach der kunic Gunther nv lat in her gan ### hat er sichs gervemet daz sol er horen lan ### oder sin mvz lovgen der helt vz Niderlant ### den Chriemh' <vriedel> hiez man bringen sa zehant
| ### Do der herre [33r]Sivrit die ungemvoten sach ### ern wiste niht der mære wie balde er do sprach ### waz weinent dise frowen daz het ich gerne erchant ### oder von welhen schulden der kunic habe nach mir gesant
###### 865 | ### Do sprach der chunic Gunther daz ist mir durch dich leit ### mir hat min frowe Prunh' ein mære hie geseit ### dv habst dich des gervmet daz dv ir schonen lip ### erste habest geminnet daz seit frowe Chriemh' din wip
###### 866 | ### Do sprach der herre Sivrit un– hat si daz geseit ### e daz ich erwinde ez sol ir werden leit ### un– wil dir daz enpfuren vor allen dinen man ### mit minen hohen eiden daz ichs ir niht gesaget han
###### 867 | ### Do sprach der kunich von Rine daz soltv lazen sehen ### daz gerihte daz dv bivtest vn– mac daz hie geschehn ### aller valscen dinge wil ich dich ledic lan ### man hiez zvo zeime ringe die stolzen Buregonde gan
| ### Sivrit gein dem eide hohe bot die hant ### do sprach der kunic riche mir ist so wol erchant ### iwer groz vnschulde ich wil ivch ledic lan ### des ivch min swester zihet daz ir des nine habt getan
###### 869 | ### Do sprach aber Sivrit genivzet es min wip ### daz si so hat betrubet den Prunhilde lip ### daz ist mir sicherlichen ane maze leit ### do sahen zvo zein ander die guten ritter gemeit
###### 870 | ### Man sol so frowen ziehen sprach Sivrit der degn ### daz si vppekliche spruche lazen vnder wegen ### verbivt ez dime wibe der minen tvon ich sam ### ir grozen vnfvge ich mih wærlichen scam
###### 871 | ### Mit rede was gescheiden manic schone wip ### do trvret also sere der Prunh' lip ### daz ez erbarmen mvose die Guntheres man ### do chom von Tronege Hagene zv siner frowen gegan
###### 872 | ### Er <vragte> waz ir wære weinende er si vant ### do sagtes im div mære er lobt ir sa zehant ### daz ez erarnen mvse der <Chriemhilde> man ### oder ern wolde nimmer dar vmbe vrolich gestan
| ### Zv der rede chom Ortwin vn– ovch Gernot ### da die helde rieten den Sivrides tot ### dar zvo chom ovch <Giselher> der edeln Vten kint ### do er ir rede gehorte er sprach vil gutlichen sint
###### 874 | ### Owe ir guten knehte warvmbe tvot ir daz ### iane gediente Sivrit nie alsolhen haz ### daz er darvmbe solde verliesen sinen lip ### ia ist es harte lihte darvmbe zvrnent div wip
###### 875 | ### Svln wir govche ziehen sprach aber Hagene ### des habent lvzzil ere so gvte degene ### daz er sich hat gervemet der lieben frowen min ### darvmbe wil ich sterben ez enge im an daz leben sin
###### 876 | ### Do sprach der kunic Gvnther ern hat uns niht getan ### wan getriwer dienste man sol in lebn lan ### waz tovg ob wir dem degene wærn nv gehaz ### er was vns ie getriwe vn– tet vil willechliche daz
| ### Do sprach vzer Mezzen der degen Ortwin ### iane kan in niht gehelfen div groze sterche sin ### erlovbt mirz min [33v]herre ez mvoz im werden leit ### do heten im die degene ane schulde widerseit
###### 878 | ### Do liezen siz beliben spilen man do sach ### hey waz man starcher schefte vor dem munster brach ### vor Sivrides wibe alzvo dem sale dan ### do wrden in vnmvote genvge Guntheres man
###### 879 | ### Sin gevolgete niemen niwan daz Hagene ### riet alle cite Gunther dem degene ### ob Sivrit niht enlebte so wrde in vndertan ### vil der kunige lande der helt do trvoren began
###### 880 | ### Er sprach nv lat beliben den mortlichen zorn ### er ist uns ze selden vn– zen eren geborn ### ovch ist so grimme chvene der vil starche man ### ob er sin innen wrde sone torst in niemen bestan
###### 881 | ### Nein ich sprach do Hagene ir mvgt wol stille dagn ### ich kanz heinliche wol also an getragen ### daz Prunh' weinen sol im werden leit ### ia mvoz im von Hagene immer wesn widerseit
| ### Do sprach der kunic Gunther wie mohte daz ergan ### des antwrt im Hagene ich wilz ivch horen lan ### wir heizen boten riten zv zvns in daz lant ### widersagen offenliche die hie niemen sin bechant
###### 883 | ### So iehet vor den gesten daz ir vn– iwer man ### wellet herverten also daz ist getan ### so lobt er in die reise des vlivset er den lip ### da man in mac verhowen div nnære saget mir sin wip
###### 884 | ### Der kunic gevolget vbele Hagene sinem man ### vil michel vntriwe begunden tragen an ### ê iemen daz erfunde die rechen vz erchorn ### von zweier frowen bagen wart vil der degene verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>